==> visionsdk-0.6.697-sources.jar: com/segway/robot/sdk/vision/utils/SharedPrefUtils.java <==
package com.segway.robot.sdk.vision.utils;

import android.content.Context;
import android.content.SharedPreferences;
import android.util.Log;

import java.util.Map;

/**
 * Created by gaominghui on 2018/11/6.
 ***/
public class SharedPrefUtils {

    private static final String TAG = "SharedPrefUtils";
    private static SharedPreferences sharedPreferences;
    private static final String FILE_NAME = "intrisic_ext";
    private static final String BASE_KEY = "rk_sensor_intrinsics";
    private static SharedPreferences.Editor editor;

    private SharedPrefUtils() {
    }

    public static void initWithContext(Context context) {
        sharedPreferences = context.getSharedPreferences(FILE_NAME, Context.MODE_PRIVATE);
    }

    public static void putIntrinsicsByType(int streamType, String intrinsics) {
        Log.d(TAG, "putIntrinsicsByType: streamType " + streamType + " intrinsics " + intrinsics);
        editor = sharedPreferences.edit();
        editor.putString(BASE_KEY + streamType, intrinsics);
        editor.apply();
    }

    public static String getIntrinsicsByType(int streamType) {
        String intrinsics = sharedPreferences.getString(BASE_KEY + streamType, "");
        Log.d(TAG, "getIntrinsicsByType: " + streamType + " " + intrinsics);
        return intrinsics;
    }

    public static void put(String key, Object object) {
        editor = sharedPreferences.edit();
        if (object instanceof String) {
            editor.putString(key, (String) object);
        } else if (object instanceof Integer) {
            editor.putInt(key, (Integer) object);
        } else if (object instanceof Boolean) {
            editor.putBoolean(key, (Boolean) object);
        } else if (object instanceof Float) {
            editor.putFloat(key, (Float) object);
        } else if (object instanceof Long) {
            editor.putLong(key, (Long) object);
        } else {
            editor.putString(key, object.toString());
        }
        editor.apply();
    }

    public static Object get(String key, Object defaultObject) {
        if (defaultObject instanceof String) {
            return sharedPreferences.getString(key, (String) defaultObject);
        } else if (defaultObject instanceof Integer) {
            return sharedPreferences.getInt(key, (Integer) defaultObject);
        } else if (defaultObject instanceof Boolean) {
            return sharedPreferences.getBoolean(key, (Boolean) defaultObject);
        } else if (defaultObject instanceof Float) {
            return sharedPreferences.getFloat(key, (Float) defaultObject);
        } else if (defaultObject instanceof Long) {
            return sharedPreferences.getLong(key, (Long) defaultObject);
        } else {
            return sharedPreferences.getString(key, null);
        }
    }

    public static void remove(String key) {
        editor.remove(key);
        editor.apply();
    }

    public static void clear() {
        editor.clear();
        editor.apply();
    }

    public static boolean contains(int key) {
        return sharedPreferences.contains(BASE_KEY + key);
    }

    public static Map<String, ?> getAll() {
        return sharedPreferences.getAll();
    }

}

==> visionsdk-0.6.855-sources.jar: com/segway/robot/sdk/vision/utils/SharedPrefUtils.java <==
package com.segway.robot.sdk.vision.utils;

import android.content.Context;
import android.content.SharedPreferences;

import com.segway.robot.sdk.base.log.Logger;

import java.util.Map;

/**
 * Created by gaominghui on 2018/11/6.
 ***/
public class SharedPrefUtils {

    private static final String TAG = "SharedPrefUtils";
    private static SharedPreferences sharedPreferences;
    private static final String FILE_NAME = "intrisic_ext";
    private static final String BASE_KEY = "rk_sensor_intrinsics";
    private static SharedPreferences.Editor editor;

    private SharedPrefUtils() {
    }

    public static void initWithContext(Context context) {
        sharedPreferences = context.getSharedPreferences(FILE_NAME, Context.MODE_PRIVATE);
    }

    public static synchronized void putIntrinsicsByType(int streamType, String intrinsics) {
        Logger.v(TAG, "putIntrinsicsByType: streamType " + streamType + " intrinsics " + intrinsics);
        editor = sharedPreferences.edit();
        editor.putString(BASE_KEY + streamType, intrinsics);
        editor.apply();
    }

    public static synchronized String getIntrinsicsByType(int streamType) {
        String intrinsics = sharedPreferences.getString(BASE_KEY + streamType, "");
        Logger.v(TAG, "getIntrinsicsByType: " + streamType + " " + intrinsics);
        return intrinsics;
    }

    public static void put(String key, Object object) {
        editor = sharedPreferences.edit();
        if (object instanceof String) {
            editor.putString(key, (String) object);
        } else if (object instanceof Integer) {
            editor.putInt(key, (Integer) object);
        } else if (object instanceof Boolean) {
            editor.putBoolean(key, (Boolean) object);
        } else if (object instanceof Float) {
            editor.putFloat(key, (Float) object);
        } else if (object instanceof Long) {
            editor.putLong(key, (Long) object);
        } else {
            editor.putString(key, object.toString());
        }
        editor.apply();
    }

    public static Object get(String key, Object defaultObject) {
        if (defaultObject instanceof String) {
            return sharedPreferences.getString(key, (String) defaultObject);
        } else if (defaultObject instanceof Integer) {
            return sharedPreferences.getInt(key, (Integer) defaultObject);
        } else if (defaultObject instanceof Boolean) {
            return sharedPreferences.getBoolean(key, (Boolean) defaultObject);
        } else if (defaultObject instanceof Float) {
            return sharedPreferences.getFloat(key, (Float) defaultObject);
        } else if (defaultObject instanceof Long) {
            return sharedPreferences.getLong(key, (Long) defaultObject);
        } else {
            return sharedPreferences.getString(key, null);
        }
    }

    public static void remove(String key) {
        editor.remove(key);
        editor.apply();
    }

    public static void clear() {
        editor.clear();
        editor.apply();
    }

    public static boolean contains(int key) {
        return sharedPreferences.contains(BASE_KEY + key);
    }

    public static Map<String, ?> getAll() {
        return sharedPreferences.getAll();
    }

}
